"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Custom elements registry.
 */
var CustomElementRegistry = /** @class */ (function () {
    function CustomElementRegistry() {
        this.registry = {};
        this.callbacks = {};
    }
    /**
     * Defines a custom element class.
     *
     * @param {string} tagName Tag name of element.
     * @param {typeof HTMLElement} elementClass Element class.
     */
    CustomElementRegistry.prototype.define = function (tagName, elementClass) {
        this.registry[tagName.toLowerCase()] = elementClass;
        if (this.callbacks[tagName]) {
            for (var _i = 0, _a = this.callbacks[tagName]; _i < _a.length; _i++) {
                var callback = _a[_i];
                callback();
            }
            delete this.callbacks[tagName];
        }
    };
    /**
     * Returns a defined element class.
     *
     * @param {string} tagName Tag name of element.
     * @param {typeof HTMLElement} HTMLElement class defined.
     */
    CustomElementRegistry.prototype.get = function (tagName) {
        return this.registry[tagName.toLowerCase()];
    };
    /**
     * Upgrades it.
     */
    CustomElementRegistry.prototype.upgrade = function () { };
    /**
     * When defined.
     *
     * @param {string} tagName Tag name of element.
     * @return {Promise<void>} Promise.
     */
    CustomElementRegistry.prototype.whenDefined = function (tagName) {
        var _this = this;
        if (this.get(tagName)) {
            return Promise.resolve();
        }
        return new Promise(function (resolve) {
            _this.callbacks[tagName] = _this.callbacks[tagName] || [];
            _this.callbacks[tagName].push(resolve);
        });
    };
    return CustomElementRegistry;
}());
exports.default = CustomElementRegistry;
//# sourceMappingURL=CustomElementRegistry.js.map