import Node from './Node';
import Element from './Element';
import NodeType from './NodeType';
/**
 * DocumentFragment.
 */
export default class DocumentFragment extends Node {
    nodeType: NodeType;
    mode: string;
    /**
     * Returns children.
     *
     * @return {Element[]} Children.
     */
    readonly children: Element[];
    /**
     * Query CSS selector to find matching nodes.
     *
     * @param  {string} selector CSS selector.
     * @return {Element[]} Matching elements.
     */
    querySelectorAll(selector: string): Element[];
    /**
     * Query CSS Selector to find matching node.
     *
     * @param  {string} selector CSS selector.
     * @return {Element} Matching node.
     */
    querySelector(selector: string): Element;
    /**
     * Returns an element by ID.
     *
     * @param {string} id ID.
     * @return {Element} Matching node.
     */
    getElementById(id: string): Element;
    /**
     * Returns an elements by tag name.
     *
     * @param {string} tagName Tag name.
     * @return {Element[]} Matching nodes.
     */
    getElementsByTagName(tagName: string): Element[];
    /**
     * Returns an elements by class name.
     *
     * @param {string} className Tag name.
     * @return {Element[]} Matching nodes.
     */
    getElementsByClassName(className: string): Element[];
}
